@@ -49,8 +49,13 @@
 /* not supported */
 #define SA_RESTART 0
 #define O_RSYNC 0
+#ifdef NEXTSTEP3_HPPA
+/* replace with corresponding bsd call */
+#define setsid() setpgrp(0, getpid())
+#else /* NEXTSTEP3_HPPA */
 /* select, ftruncate, fchmod */
 #include <libc.h>
+#endif /* NEXTSTEP3_HPPA */
 /* in ansi string.h but undefined in -posix */
 #define bzero(b,len) memset(b,0,len)
 #define SIZEOF_IS_LONG_INT
@@ -74,7 +79,7 @@
 #endif
 
 #ifdef AIX43
-if defined(__64BIT_KERNEL) && defined(_KERNEL)
+#if defined(__64BIT_KERNEL) && defined(_KERNEL)
 #define PID_T_IS_LONG_INT
 #endif /* __64BIT_KERNEL && _KERNEL */
 #define SIZEOF_IS_LONG_INT
@@ -90,6 +95,7 @@ if defined(__64BIT_KERNEL) && defined(_KERNEL)
 
 #ifdef UNIXWARE7
 #define HAVE_GETRUSAGE
+#define PID_T_IS_LONG_INT
 #define O_RSYNC		0
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP    "/var/tmp"
@@ -97,6 +103,14 @@ if defined(__64BIT_KERNEL) && defined(_KERNEL)
 #define PATH_WTMP       "/var/adm/wtmp"
 #define PATH_UTMP       "/etc/utmp"
 #define PATH_SYSLOG     "/var/adm/syslog"
+/*
+ * Strange thing on Unixware 7, sockets manifest itself as FIFOs
+ * John Hughes <john@Calva.COM>
+ */
+#ifdef S_ISSOCK
+#undef S_ISSOCK
+#define	S_ISSOCK	S_ISFIFO
+#endif
 #endif
 
 #ifndef RANDSAVENAME
